==> kaspaliste-0.4.tar.gz: kaspaliste-0.4/kaspaliste/kliste/bibtexfile.h <==
/***************************************************************************
                          bibtexfile.h  -  description
                             -------------------
    begin                : Sun Jan 7 2001
    copyright            : (C) 2001 by Jan Mueller
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/**********************************************************************

	--- Qt Architect generated file ---

	File: bibtexfile.h
	Last generated: Sat Jul 29 01:20:05 2000

 *********************************************************************/

#ifndef BibTexFile_included
#define BibTexFile_included

#include "bibtexfiledata.h"
#include "kaspabase.h"

class BibTexFile : public BibTexFileData, protected Sql
{
    Q_OBJECT

private:
		BibTexFile(const BibTexFile&);
		BibTexFile& operator=(const BibTexFile&);
		bool cancelaction;

public:
    BibTexFile(QWidget* parent = 0L, const char* name = 0L);
    virtual ~BibTexFile();

		int exec() { return BibTexFileData::exec(); }

public slots:
	void start();
	void cancel();
};
#endif // BibTexFile_included

==> kaspaliste-0.96.tar.gz: kaspaliste-0.96/kaspaliste/kliste/bibtexfile.h <==
/***************************************************************************
                          bibtexfile.h  -  description
                             -------------------
    begin                : Sun Jan 7 2001
    copyright            : (C) 2001 by Jan Mueller
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/**********************************************************************

	--- Qt Architect generated file ---

	File: bibtexfile.h
	Last generated: Sat Jul 29 01:20:05 2000

 *********************************************************************/

#ifndef BibTexFile_included
#define BibTexFile_included

#include "bibtexfiledata.h"
#include "kaspabase.h"
#include "kliste.h"

class BibTexFile : public BibTexFileData, protected Sql
{
    Q_OBJECT

private:
		BibTexFile(const BibTexFile&);
		BibTexFile& operator=(const BibTexFile&);
		bool cancelaction;

public:
    BibTexFile(QWidget* parent, const char* name, Sql &conn);
    virtual ~BibTexFile() throw();

		int exec() { return BibTexFileData::exec(); }

public slots:
	void start();
	void cancel();
};
#endif // BibTexFile_included
